import * as THREE from 'three';
import { BBox, LngLat, MapOptions, Point2 } from './types';
import BaseLayer from './layers/BaseLayer';
import BaseBeforeLayer from './layers/BaseBeforeLayer';
declare class Map extends THREE.EventDispatcher {
    tileSize: number;
    readonly earthRadius = 6371;
    readonly renderer: THREE.WebGLRenderer;
    readonly scene: THREE.Scene;
    readonly hash: boolean;
    private readonly earthOrbitControls;
    private readonly earthGeometry;
    private readonly earthMesh;
    private readonly container;
    private layerManager;
    private readonly beforeLayerManager;
    private tileLayer;
    private disposeFuncList;
    /**
     * 安全区域，如果 displayBBox 超出了安全区域，则需要更新 preloadBBox
     */
    secureBBox?: BBox;
    constructor(options: MapOptions);
    addBackground(): void;
    private updatePreloadBBox;
    private initEarthOrbitControls;
    private getPreloadBBox;
    private getSecureBBox;
    private parseHash;
    private updateHash;
    private initEarthMaterial;
    private inContainerRange;
    /**
     * 将 LngLat 转化为像素位置
     * @param lngLat
     * @param options.allowNotVisible
     * @returns
     */
    project(lngLat: LngLat, options?: {
        allowNotVisible?: Boolean;
    }): Point2 | null;
    /**
     * 将像素位置转化为 LngLat
     * 为什么不使用 THREE.Raycaster: https://github.com/mrdoob/three.js/issues/11449
     * @param point
     * @param options.allowFovLimitExceeded 是否允许该点对应的视角超出球体相切角度，如果为 true，即便超出相切角度，也会将其转化为相切角度然后返回经纬度
     * @returns
     */
    unproject(point: Point2, options?: {
        allowFovLimitExceeded?: boolean;
    }): LngLat | null;
    getDisplayPolygon(): import("@turf/turf").Feature<import("@turf/turf").Polygon, import("@turf/turf").Properties>;
    addLayer(layer: BaseLayer | BaseBeforeLayer): void;
    removeLayer(layer: BaseLayer | BaseBeforeLayer): void;
    private clearContainer;
    dispose(): void;
}
export default Map;
